@@ -8,4 +8,4 @@ def main():
 
     args = parser.parse_args()
 
-    badsql.db([''.join([str(x) for x in y] for y in args.headers]).display()
+    badsql.db(''.join([str(x) for x in y] for y in args.headers)).display()
